@@ -8,7 +8,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2018 Pascal Buchbinder
+ * Copyright (C) 2019 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -27,7 +27,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsgeo.c 2486 2018-09-03 20:22:17Z pbuchbinder $";
+static const char revision[] = "$Id: qsgeo.c 2572 2019-08-28 20:48:40Z pbuchbinder $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -58,7 +58,7 @@ static const char revision[] = "$Id: qsgeo.c 2486 2018-09-03 20:22:17Z pbuchbind
 // "3758096128","3758096383","AU","Australia"
 #define QS_GEO_PATTERN_D "\"([0-9]+)\",\"([0-9]+)\",\"([A-Z0-9]{2})\",\"(.*)\""
 // "192.83.198.0","192.83.198.255","3226715648","3226715903","AU","Australia"
-#define QS_GEO_PATTERN_EXT  "\"[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+\",\"[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+\",\"([0-9]+)\",\"([0-9]+)\",\"([A-Z0-9]{2})\",\"(.*)\""
+#define QS_GEO_PATTERN_EXT  "\"[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+\",\"[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+\",\"([0-9]+)\",\"([0-9]+)\",\"([A-Z0-9]{2})\""
 // 182.12.34.23
 #define IPPATTERN "([0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3})[\"'\x0d\x0a, ]+"
 #define IPPATTERN2 "([0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3})[\"'\x0d\x0a,; ]+"
@@ -214,21 +214,21 @@ static void usage(const char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH EXAMPLE\n");
-    printf("Reading the file access_log and adding the country code to the IP address field:\n");
+    printf("Reading the file access.log and adding the country code to the IP address field:\n");
     printf("\n");
   } else {
-    printf("Example reading the file access_log and adding the country code to\n");
+    printf("Example reading the file access.log and adding the country code to\n");
     printf("the IP address field:\n");
   }
-  qs_man_println(man, "  cat access_log | %s -d GeoIPCountryWhois.csv\n", cmd);
+  qs_man_println(man, "  cat access.log | %s -d GeoIPCountryWhois.csv\n", cmd);
   printf("\n");
   if(man) {
-    printf("Reading the file access_log and showing a summary only:\n");
+    printf("Reading the file access.log and showing a summary only:\n");
     printf("\n");
   } else {
-    printf("Example reading the file access_log and showing a summary only:\n");
+    printf("Example reading the file access.log and showing a summary only:\n");
   }
-  qs_man_println(man, "  cat access_log | %s -d GeoIPCountryWhois.csv -s\n", cmd);
+  qs_man_println(man, "  cat access.log | %s -d GeoIPCountryWhois.csv -s\n", cmd);
   printf("\n");
   if(man) {
     printf("Resolving a single IP address:\n");
