@@ -6,7 +6,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2018 Pascal Buchbinder
+ * Copyright (C) 2019 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -24,7 +24,7 @@
  * limitations under the License.
  */
 
-static const char revision[] = "$Id: qssign.c 2486 2018-09-03 20:22:17Z pbuchbinder $";
+static const char revision[] = "$Id: qssign.c 2582 2019-10-21 16:22:45Z pbuchbinder $";
 
 #include <stdio.h>
 #include <unistd.h>
@@ -310,7 +310,7 @@ void qs_signal_exit(int e) {
 }
 
 /**
- * Tries to find out a suiteable log line format which is used
+ * Tries to find out a suitable log line format which is used
  * to log sign end messages (so let the verifier known, that the
  * data ends nothing has been cut off).
  *
@@ -517,7 +517,7 @@ static long qs_verify(const char *sec) {
       if(strcmp(m, sig) != 0) {
 	err++;
 	fprintf(stderr, "ERROR on line %ld: invalid signature\n", lineNumber);
-	/* message may be modified/currupt or inserted: next line may have
+	/* message may be modified/corrupt or inserted: next line may have
 	   the next sequence number (modified) or the same (inserted) */
 	nr_alt = m_nr + 1;
 	nr_alt_lineNumber = lineNumber + 1;
@@ -534,9 +534,9 @@ static long qs_verify(const char *sec) {
       } else {
 	if(m_nr != -1) {
 	  if(lineNumber == nr_alt_lineNumber) {
-	    // last line was modfied
+	    // last line was modified
 	    if(m_nr != msgSeqNr) {
-	      // and therefore, we also accept the next seqence number
+	      // and therefore, we also accept the next sequence number
 	      m_nr = nr_alt;
 	    }
 	    nr_alt = -1;
@@ -629,7 +629,7 @@ static void usage(char *cmd, int man) {
   }
   qs_man_print(man, "%s is a log data integrity check tool. It reads log data\n", cmd);
   qs_man_print(man, "from stdin (pipe) and writes the data to stdout adding a sequence\n");
-  qs_man_print(man, "number and signatur to ever log line.\n");
+  qs_man_print(man, "number and signature to ever log line.\n");
   printf("\n");
   if(man) {
     printf(".SH OPTIONS\n");
@@ -673,7 +673,7 @@ static void usage(char *cmd, int man) {
   } else {
     printf("Example (sign):\n");
   }
-  qs_man_println(man, " TransferLog \"|/bin/%s -s password -e |/bin/qsrotate -o /var/log/apache/access_log\"\n", cmd);
+  qs_man_println(man, " TransferLog \"|/usr/bin/%s -s password -e |/usr/bin/qsrotate -o /var/log/apache/access.log\"\n", cmd);
   printf("\n");
   if(man) {
     printf("\n");
@@ -682,7 +682,7 @@ static void usage(char *cmd, int man) {
   } else {
     qs_man_print(man, "Example (verify):\n");
   }
-  qs_man_println(man, " cat access_log | %s -s password -v\n", cmd);
+  qs_man_println(man, " cat access.log | %s -s password -v\n", cmd);
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
